@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: CJKFont.pm,v 1.15 2003/04/09 11:13:12 fredo Exp $
+#   $Id: CJKFont.pm,v 2.1 2007/03/17 20:38:51 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::CJKFont;
@@ -40,7 +40,6 @@ BEGIN {
     use PDF::API2::Util;
     use PDF::API2::Basic::PDF::Utils;
     use PDF::API2::Resource::CIDFont;
-    use PDF::API2::IOString;
 
     use PDF::API2::Basic::TTF::Font;
 
@@ -50,7 +49,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::CIDFont );
 
-    ( $VERSION ) = '$Revision: 1.15 $' =~ /Revision: (\S+)\s/; # $Date: 2003/04/09 11:13:12 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/03/17 20:38:51 $
 
     $fonts = { };
     $cmap = { };
@@ -382,6 +381,24 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CJKFont.pm,v $
+    Revision 2.1  2007/03/17 20:38:51  areibens
+    replaced IOString dep. with scalar IO.
+
+    Revision 2.0  2005/11/16 02:16:04  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:25  areibens
+    genesis
+
+    Revision 1.17  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.16  2005/06/17 18:53:34  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
     Revision 1.15  2003/04/09 11:13:12  fredo
     added/fixed proper alias/substitutions
 
