@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: DeviceN.pm,v 1.5 2005/06/17 19:44:03 fredo Exp $
+#   $Id: DeviceN.pm,v 2.0 2005/11/16 02:18:14 areibens Exp $
 #
 #=======================================================================
 
@@ -43,7 +43,7 @@ BEGIN {
     use Math::Trig;
 
     @ISA = qw( PDF::API2::Resource::ColorSpace );
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.5 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:03 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:18:14 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -149,6 +149,15 @@ __END__
 =head1 HISTORY
 
     $Log: DeviceN.pm,v $
+    Revision 2.0  2005/11/16 02:18:14  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
     Revision 1.5  2005/06/17 19:44:03  fredo
     fixed CPAN modulefile versioning (again)
 
