@@ -27,14 +27,15 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: georgiaitalic.pm,v 1.6 2005/03/14 22:01:29 fredo Exp $
+#   $Id: georgiaitalic.pm,v 2.0 2005/11/16 02:18:15 areibens Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::georgiaitalic;
 
-$fonts->{georgiaitalic}= {
+$FONTDATA = {
     'fontname' => 'Georgia,Italic',
     'type' => 'TrueType',
-    'apiname' => 'Ge4',
+    'apiname' => 'GeIt',
     'ascender' => '916',
     'capheight' => '692',
     'descender' => '-219',
@@ -894,6 +895,21 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: georgiaitalic.pm,v $
+    Revision 2.0  2005/11/16 02:18:15  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.8  2005/09/12 16:56:21  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
+    Revision 1.7  2005/06/07 23:21:39  fredo
+    fontkey correction
+
     Revision 1.6  2005/03/14 22:01:29  fredo
     upd 2005
 
