@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,11 +27,12 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: symbol.pm,v 1.5 2004/06/15 09:14:53 fredo Exp $
+#   $Id: symbol.pm,v 2.0 2005/11/16 02:18:15 areibens Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::symbol;
 
-$fonts->{symbol}= {
+$FONTDATA = {
     'fontname' => 'Symbol',
     'type' => 'Type1',
     'apiname' => 'Sym',
@@ -512,6 +513,21 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: symbol.pm,v $
+    Revision 2.0  2005/11/16 02:18:15  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.7  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
+    Revision 1.6  2005/03/14 22:01:29  fredo
+    upd 2005
+
     Revision 1.5  2004/06/15 09:14:53  fredo
     removed cr+lf
 
