@@ -27,14 +27,15 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: verdanabold.pm,v 1.6 2005/03/14 22:01:30 fredo Exp $
+#   $Id: verdanabold.pm,v 2.0 2005/11/16 02:18:15 areibens Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::verdanabold;
 
-$fonts->{verdanabold}= {
+$FONTDATA = {
     'fontname' => 'Verdana,Bold',
     'type' => 'TrueType',
-    'apiname' => 'Ve2',
+    'apiname' => 'VeBo',
     'ascender' => '1005',
     'capheight' => '727',
     'descender' => '-209',
@@ -879,6 +880,21 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: verdanabold.pm,v $
+    Revision 2.0  2005/11/16 02:18:15  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.8  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
+    Revision 1.7  2005/06/07 23:21:40  fredo
+    fontkey correction
+
     Revision 1.6  2005/03/14 22:01:30  fredo
     upd 2005
 
